==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/WsfcDomainCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Domain credentials for setting up Windows Server Failover Cluster for SQL availability group.
 * @property clusterBootstrapAccountPassword Cluster bootstrap account password.
 * @property clusterOperatorAccountPassword Cluster operator account password.
 * @property sqlServiceAccountPassword SQL service account password.
 */
public data class WsfcDomainCredentialsArgs(
    public val clusterBootstrapAccountPassword: Output<String>? = null,
    public val clusterOperatorAccountPassword: Output<String>? = null,
    public val sqlServiceAccountPassword: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs.builder()
            .clusterBootstrapAccountPassword(clusterBootstrapAccountPassword?.applyValue({ args0 -> args0 }))
            .clusterOperatorAccountPassword(clusterOperatorAccountPassword?.applyValue({ args0 -> args0 }))
            .sqlServiceAccountPassword(sqlServiceAccountPassword?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WsfcDomainCredentialsArgs].
 */
@PulumiTagMarker
public class WsfcDomainCredentialsArgsBuilder internal constructor() {
    private var clusterBootstrapAccountPassword: Output<String>? = null

    private var clusterOperatorAccountPassword: Output<String>? = null

    private var sqlServiceAccountPassword: Output<String>? = null

    /**
     * @param value Cluster bootstrap account password.
     */
    @JvmName("bnsmgtwmhjlgxvul")
    public suspend fun clusterBootstrapAccountPassword(`value`: Output<String>) {
        this.clusterBootstrapAccountPassword = value
    }

    /**
     * @param value Cluster operator account password.
     */
    @JvmName("ljtvevvblfooqdvr")
    public suspend fun clusterOperatorAccountPassword(`value`: Output<String>) {
        this.clusterOperatorAccountPassword = value
    }

    /**
     * @param value SQL service account password.
     */
    @JvmName("oftksxqqiutjarsn")
    public suspend fun sqlServiceAccountPassword(`value`: Output<String>) {
        this.sqlServiceAccountPassword = value
    }

    /**
     * @param value Cluster bootstrap account password.
     */
    @JvmName("kjtlmrvygsmkfsnd")
    public suspend fun clusterBootstrapAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterBootstrapAccountPassword = mapped
    }

    /**
     * @param value Cluster operator account password.
     */
    @JvmName("mjibxtefrxscrhpq")
    public suspend fun clusterOperatorAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterOperatorAccountPassword = mapped
    }

    /**
     * @param value SQL service account password.
     */
    @JvmName("mdhtlxewuwiunvug")
    public suspend fun sqlServiceAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlServiceAccountPassword = mapped
    }

    internal fun build(): WsfcDomainCredentialsArgs = WsfcDomainCredentialsArgs(
        clusterBootstrapAccountPassword = clusterBootstrapAccountPassword,
        clusterOperatorAccountPassword = clusterOperatorAccountPassword,
        sqlServiceAccountPassword = sqlServiceAccountPassword,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/WsfcDomainCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Domain credentials for setting up Windows Server Failover Cluster for SQL availability group.
 * @property clusterBootstrapAccountPassword Cluster bootstrap account password.
 * @property clusterOperatorAccountPassword Cluster operator account password.
 * @property sqlServiceAccountPassword SQL service account password.
 */
public data class WsfcDomainCredentialsArgs(
    public val clusterBootstrapAccountPassword: Output<String>? = null,
    public val clusterOperatorAccountPassword: Output<String>? = null,
    public val sqlServiceAccountPassword: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.WsfcDomainCredentialsArgs.builder()
            .clusterBootstrapAccountPassword(clusterBootstrapAccountPassword?.applyValue({ args0 -> args0 }))
            .clusterOperatorAccountPassword(clusterOperatorAccountPassword?.applyValue({ args0 -> args0 }))
            .sqlServiceAccountPassword(sqlServiceAccountPassword?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WsfcDomainCredentialsArgs].
 */
@PulumiTagMarker
public class WsfcDomainCredentialsArgsBuilder internal constructor() {
    private var clusterBootstrapAccountPassword: Output<String>? = null

    private var clusterOperatorAccountPassword: Output<String>? = null

    private var sqlServiceAccountPassword: Output<String>? = null

    /**
     * @param value Cluster bootstrap account password.
     */
    @JvmName("cwukbtvxsejleetk")
    public suspend fun clusterBootstrapAccountPassword(`value`: Output<String>) {
        this.clusterBootstrapAccountPassword = value
    }

    /**
     * @param value Cluster operator account password.
     */
    @JvmName("etyfvimrgaftedit")
    public suspend fun clusterOperatorAccountPassword(`value`: Output<String>) {
        this.clusterOperatorAccountPassword = value
    }

    /**
     * @param value SQL service account password.
     */
    @JvmName("qinkdyclqfuqapot")
    public suspend fun sqlServiceAccountPassword(`value`: Output<String>) {
        this.sqlServiceAccountPassword = value
    }

    /**
     * @param value Cluster bootstrap account password.
     */
    @JvmName("mnoccaebmynliucp")
    public suspend fun clusterBootstrapAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterBootstrapAccountPassword = mapped
    }

    /**
     * @param value Cluster operator account password.
     */
    @JvmName("gyofmkbeuuleeuly")
    public suspend fun clusterOperatorAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clusterOperatorAccountPassword = mapped
    }

    /**
     * @param value SQL service account password.
     */
    @JvmName("fmgrsvjthjbkvfnd")
    public suspend fun sqlServiceAccountPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlServiceAccountPassword = mapped
    }

    internal fun build(): WsfcDomainCredentialsArgs = WsfcDomainCredentialsArgs(
        clusterBootstrapAccountPassword = clusterBootstrapAccountPassword,
        clusterOperatorAccountPassword = clusterOperatorAccountPassword,
        sqlServiceAccountPassword = sqlServiceAccountPassword,
    )
}
